import { cloneObject, includes } from "@esri/hub-common";
import { getSiteItemType } from "./get-site-item-type";
/**
 * Enture that the site model has the correct type and tags
 * Mutates the Model
 * @param {Object} model Site Model
 * @param {Object} currentUser Current User
 * @param {Boolean} isPortal Is this running in ArcGIS Enterprise
 * @private
 */
export function _ensureTypeAndTags(model, isPortal) {
    model = cloneObject(model);
    model.item.type = getSiteItemType(isPortal);
    // ensure typekeywords array
    if (!Array.isArray(model.item.typeKeywords)) {
        model.item.typeKeywords = [];
    }
    if (!includes(model.item.typeKeywords, "hubSite")) {
        model.item.typeKeywords.push("hubSite");
    }
    return model;
}
//# sourceMappingURL=_ensure-type-and-tags.js.map