import { deepSet, getProp, migrateWebMappingApplicationSites, } from "@esri/hub-common";
import { SITE_SCHEMA_VERSION, _ensureTelemetry, _migrateFeedConfig, _migrateEventListCardConfigs, _migrateTelemetryConfig, migrateBadBasemap, } from "@esri/hub-common";
const schemaVersionPath = "item.properties.schemaVersion";
const initialDraftVersion = 1.3;
/**
 * Applies the schema upgrades
 * @param draft IDraft
 */
export function upgradeDraftSchema(draft) {
    if (getProp(draft, "item.properties.schemaVersion") === undefined) {
        deepSet(draft, schemaVersionPath, initialDraftVersion);
    }
    // Migrations that should always be applied
    draft = migrateBadBasemap(draft);
    draft = migrateWebMappingApplicationSites(draft);
    if (getProp(draft, "item.properties.schemaVersion") === SITE_SCHEMA_VERSION) {
        return draft;
    }
    else {
        let migrated = draft;
        // apply site schema upgrade functions in order...
        // don't have do do them all since drafts only got released
        // at version 1.3
        migrated = _ensureTelemetry(draft);
        migrated = _migrateFeedConfig(draft);
        migrated = _migrateEventListCardConfigs(draft);
        migrated = _migrateTelemetryConfig(draft);
        return migrated;
    }
}
//# sourceMappingURL=upgrade-draft-schema.js.map