import { cloneObject } from "@esri/hub-common";
import { convertSection } from "./convert-section";
/**
 * Convert a layout to a templatized version of itself
 * @param {ILayout} layout the layout to templatize
 */
export function convertLayoutToTemplate(layout) {
    if (!layout) {
        return null;
    }
    // walk the sections, rows, cards... then call to fn's to convert specific cards...
    const converted = layout.sections.reduce((acc, section) => {
        const _result = convertSection(section);
        acc.assets = acc.assets.concat(_result.assets);
        acc.sections.push(_result.section);
        return acc;
    }, { assets: [], sections: [] });
    // assemble the response
    const result = {
        assets: converted.assets,
        layout: {
            sections: converted.sections
        }
    };
    if (layout.header) {
        result.layout.header = cloneObject(layout.header);
    }
    if (layout.footer) {
        result.layout.footer = cloneObject(layout.footer);
    }
    return result;
}
//# sourceMappingURL=convert-layout-to-template.js.map