"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports._ensureTypeAndTags = void 0;
const hub_common_1 = require("@esri/hub-common");
const get_site_item_type_1 = require("./get-site-item-type");
/**
 * Enture that the site model has the correct type and tags
 * Mutates the Model
 * @param {Object} model Site Model
 * @param {Object} currentUser Current User
 * @param {Boolean} isPortal Is this running in ArcGIS Enterprise
 * @private
 */
function _ensureTypeAndTags(model, isPortal) {
    model = hub_common_1.cloneObject(model);
    model.item.type = get_site_item_type_1.getSiteItemType(isPortal);
    // ensure typekeywords array
    if (!Array.isArray(model.item.typeKeywords)) {
        model.item.typeKeywords = [];
    }
    if (!hub_common_1.includes(model.item.typeKeywords, "hubSite")) {
        model.item.typeKeywords.push("hubSite");
    }
    return model;
}
exports._ensureTypeAndTags = _ensureTypeAndTags;
//# sourceMappingURL=_ensure-type-and-tags.js.map