"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports._removeSiteGroups = void 0;
const hub_common_1 = require("@esri/hub-common");
/**
 * Remove the well-known team groups
 * Underlying calls are failsafe so this will never throw
 * but the groups may not be deleted
 * @param {Object} siteModel Site Model
 * @param {IRequestOptions} requestOptions
 * @private
 */
function _removeSiteGroups(siteModel, requestOptions) {
    const teamsToDelete = [
        "collaborationGroupId",
        "contentGroupId",
        "followersGroupId"
    ].reduce((acc, prop) => {
        return hub_common_1.maybePush(hub_common_1.getProp(siteModel, `item.properties.${prop}`), acc);
    }, []);
    const promises = teamsToDelete.map(id => {
        const opts = Object.assign({ id }, requestOptions);
        return hub_common_1._unprotectAndRemoveGroup(opts);
    });
    return Promise.all(promises);
}
exports._removeSiteGroups = _removeSiteGroups;
//# sourceMappingURL=_remove-site-groups.js.map