"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports._secondPassAdlibPages = void 0;
const hub_common_1 = require("@esri/hub-common");
/**
 * Post process the Page models, interpolating various values which would
 * not have existed when the Page item itself was created
 * @param {object} siteModel Site Model
 * @param {object} pageModel Page Model
 * @private
 */
function _secondPassAdlibPages(siteModel, pageModel) {
    // construct a hash of teams that were created and attached to the site
    const teams = [
        "collaborationGroupId",
        "followersGroupId",
        "contentGroupId"
    ].reduce((acc, prop) => {
        const teamId = hub_common_1.getProp(siteModel, `item.properties.${prop}`);
        if (teamId) {
            acc[prop] = teamId;
        }
        return acc;
    }, {});
    const settings = {
        teams,
        siteId: hub_common_1.getProp(siteModel, "item.id"),
        siteUrl: hub_common_1.getProp(siteModel, "item.url"),
        initiative: {
            item: { id: hub_common_1.getProp(siteModel, "item.properties.parentInitiativeId") }
        }
    };
    // weld in the site itself so it can be used for some interpolations
    settings[siteModel.key] = siteModel;
    return hub_common_1.interpolate(pageModel, settings);
}
exports._secondPassAdlibPages = _secondPassAdlibPages;
//# sourceMappingURL=_second-pass-adlib-pages.js.map