"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports._updatePages = void 0;
const hub_common_1 = require("@esri/hub-common");
const arcgis_rest_portal_1 = require("@esri/arcgis-rest-portal");
const _second_pass_adlib_pages_1 = require("./_second-pass-adlib-pages");
/**
 * Locate any Page items that were created in the Solution, and link them back to the Site
 * @param {object} siteModel Site Model
 * @param {Array} solutionModels Array of all models created by the Solution
 * @param {IHubRequestOptions} hubRequestOptions
 * @private
 */
function _updatePages(siteModel, solutionModels, hubRequestOptions) {
    // 2) for any page item, check if it has the site in it's pages array and if not add it
    const pageModels = solutionModels.filter(m => {
        return m.item.type.indexOf("Page") > -1;
    });
    // Create Fail-safe version of update b/c this is not critical
    const failSafeUpdate = hub_common_1.failSafe(arcgis_rest_portal_1.updateItem, { success: true });
    // check each one of these and see if the siteModel.item.id is in it's data.value.sites array
    // if not, add and update the item
    const siteEntry = {
        id: siteModel.item.id,
        title: siteModel.item.title
    };
    // iterate the pages
    return Promise.all(pageModels.map(m => {
        m.data.values.sites.push(siteEntry);
        m = _second_pass_adlib_pages_1._secondPassAdlibPages(siteModel, m);
        return failSafeUpdate({
            item: hub_common_1.serializeModel(m),
            authentication: hubRequestOptions.authentication
        });
    }));
}
exports._updatePages = _updatePages;
//# sourceMappingURL=_update-pages.js.map