"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports._getDraftResourceNames = void 0;
const arcgis_rest_portal_1 = require("@esri/arcgis-rest-portal");
const _draft_resource_regex_1 = require("./_draft-resource-regex");
/**
 * Gets the name of the resource for the current draft.
 * NOTE: There _should_ only be one, but sometimes it gets messed up.
 * @param siteOrPageId
 * @param hubRequestOptions
 * @private
 */
function _getDraftResourceNames(siteOrPageId, hubRequestOptions) {
    return arcgis_rest_portal_1.getItemResources(siteOrPageId, {
        portal: hubRequestOptions.portal,
        authentication: hubRequestOptions.authentication
    }).then(response => {
        // search through the resources to find the draft
        const draftResourceNames = response.resources
            .map(({ resource: name }) => name)
            .filter((name) => name.search(_draft_resource_regex_1.DRAFT_RESOURCE_REGEX) !== -1);
        return draftResourceNames;
    });
}
exports._getDraftResourceNames = _getDraftResourceNames;
//# sourceMappingURL=_get-draft-resource-names.js.map