"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.upgradeDraftSchema = void 0;
const hub_common_1 = require("@esri/hub-common");
const hub_common_2 = require("@esri/hub-common");
const schemaVersionPath = "item.properties.schemaVersion";
const initialDraftVersion = 1.3;
/**
 * Applies the schema upgrades
 * @param draft IDraft
 */
function upgradeDraftSchema(draft) {
    if (hub_common_1.getProp(draft, "item.properties.schemaVersion") === undefined) {
        hub_common_1.deepSet(draft, schemaVersionPath, initialDraftVersion);
    }
    // Migrations that should always be applied
    draft = hub_common_2.migrateBadBasemap(draft);
    draft = hub_common_1.migrateWebMappingApplicationSites(draft);
    if (hub_common_1.getProp(draft, "item.properties.schemaVersion") === hub_common_2.SITE_SCHEMA_VERSION) {
        return draft;
    }
    else {
        let migrated = draft;
        // apply site schema upgrade functions in order...
        // don't have do do them all since drafts only got released
        // at version 1.3
        migrated = hub_common_2._ensureTelemetry(draft);
        migrated = hub_common_2._migrateFeedConfig(draft);
        migrated = hub_common_2._migrateEventListCardConfigs(draft);
        migrated = hub_common_2._migrateTelemetryConfig(draft);
        return migrated;
    }
}
exports.upgradeDraftSchema = upgradeDraftSchema;
//# sourceMappingURL=upgrade-draft-schema.js.map