"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureOptionalGroupsTemplating = void 0;
const hub_common_1 = require("@esri/hub-common");
/**
 * Ensure that the item template has `:optional` on the item.properties.* team
 * properties. Does not mutate the passed in object - returns a clone.
 * @param {Object} itemTemplate Item Template to work with
 */
function ensureOptionalGroupsTemplating(itemTemplate) {
    const props = ["collaborationGroupId", "contentGroupId", "followersGroupId"];
    const tmpl = hub_common_1.cloneObject(itemTemplate);
    props.forEach(prop => {
        const val = hub_common_1.getProp(tmpl, `properties.${prop}`);
        if (val) {
            if (val.match(/^\{\{.*\}\}$/)) {
                if (!val.match(/:optional\}\}$/g)) {
                    // replace it
                    tmpl.properties[prop] = val.replace("}}", ":optional}}");
                }
            }
            else {
                delete tmpl.properties[prop];
            }
        }
    });
    return tmpl;
}
exports.ensureOptionalGroupsTemplating = ensureOptionalGroupsTemplating;
//# sourceMappingURL=ensure-optional-groups-templating.js.map