"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertLayoutToTemplate = void 0;
const hub_common_1 = require("@esri/hub-common");
const convert_section_1 = require("./convert-section");
/**
 * Convert a layout to a templatized version of itself
 * @param {ILayout} layout the layout to templatize
 */
function convertLayoutToTemplate(layout) {
    if (!layout) {
        return null;
    }
    // walk the sections, rows, cards... then call to fn's to convert specific cards...
    const converted = layout.sections.reduce((acc, section) => {
        const _result = convert_section_1.convertSection(section);
        acc.assets = acc.assets.concat(_result.assets);
        acc.sections.push(_result.section);
        return acc;
    }, { assets: [], sections: [] });
    // assemble the response
    const result = {
        assets: converted.assets,
        layout: {
            sections: converted.sections
        }
    };
    if (layout.header) {
        result.layout.header = hub_common_1.cloneObject(layout.header);
    }
    if (layout.footer) {
        result.layout.footer = hub_common_1.cloneObject(layout.footer);
    }
    return result;
}
exports.convertLayoutToTemplate = convertLayoutToTemplate;
//# sourceMappingURL=convert-layout-to-template.js.map