"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCardDependencies = void 0;
const hub_common_1 = require("@esri/hub-common");
function getPaths(componentName) {
    switch (componentName) {
        case "webmap-card":
            return ["component.settings.webmap"];
        case "survey-card":
            return ["component.settings.surveyId"];
        case "app-card":
            return ["component.settings.itemId"];
        case "summary-statistic-card":
            return ["component.settings.itemId"];
        case "items/gallery-card":
            return ["component.settings.ids"];
        default:
            return [];
    }
}
/**
 * Find all the paths dependencies for the given card
 *
 * @param {ICard} card
 */
function getCardDependencies(card) {
    const componentName = hub_common_1.getProp(card, "component.name");
    const paths = getPaths(componentName);
    return paths.reduce(collectAndFlattenPropertyValues(card), []);
}
exports.getCardDependencies = getCardDependencies;
function collectAndFlattenPropertyValues(card) {
    return (acc, path) => {
        const propertyValue = hub_common_1.getProp(card, path);
        if (!propertyValue) {
            return acc;
        }
        if (Array.isArray(propertyValue)) {
            return acc.concat(propertyValue);
        }
        else {
            return acc.concat([propertyValue]);
        }
    };
}
//# sourceMappingURL=get-card-dependencies.js.map