"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureRequiredPageProperties = void 0;
const hub_common_1 = require("@esri/hub-common");
const get_page_item_type_1 = require("./get-page-item-type");
const page_type_keyword_1 = require("./page-type-keyword");
/**
 * Given a Page Model, ensure that it has all the requires properties set correctly
 * and return a new object
 * @param {Object} pageModel Page Model object
 * @param {Object} options {username, isPortal}
 */
function ensureRequiredPageProperties(pageModel, options) {
    // clone
    const result = hub_common_1.cloneObject(pageModel);
    result.item.owner = options.username;
    result.item.access = "private";
    if (!result.data.values) {
        result.data.values = {};
    }
    result.data.values.updatedAt = new Date().toISOString();
    result.data.values.updatedBy = options.username;
    if (!result.data.values.sites) {
        result.data.values.sites = [];
    }
    // NOTE: until we have hub-home, we are setting the page url to ''
    if (result.item.url) {
        result.item.url = "";
    }
    result.item.type = get_page_item_type_1.getPageItemType(options.isPortal);
    // ensure it has the typeKeyword
    if (result.item.typeKeywords.indexOf(page_type_keyword_1.PAGE_TYPE_KEYWORD) === -1) {
        result.item.typeKeywords.push(page_type_keyword_1.PAGE_TYPE_KEYWORD);
    }
    return result;
}
exports.ensureRequiredPageProperties = ensureRequiredPageProperties;
//# sourceMappingURL=ensure-required-page-properties.js.map